# SPDX-FileCopyrightText: 2025 Tymoteusz Blazejczyk <tymoteusz.blazejczyk@tymonx.com>
# SPDX-License-Identifier: Apache-2.0

"""Enabling the :py:mod:`cocotb_tools.pytest.plugin` that allows to use
`pytest`_ as the regression manager for running `cocotb`_ tests.

.. note::

    Plugin will be atuomatically enabled via entry points defined by this package.

.. _pytest: https://docs.pytest.org
.. _cocotb: https://www.cocotb.org
"""
